@@ -18,6 +18,7 @@ from datetime import timezone
 
 from google.protobuf import duration_pb2
 from google.protobuf import timestamp_pb2
+from proto import datetime_helpers, utils
 
 
 class TimestampRule:
@@ -29,20 +30,18 @@ class TimestampRule:
     proto directly.
     """
 
-    def to_python(self, value, *, absent: bool = None) -> datetime:
+    def to_python(
+        self, value, *, absent: bool = None
+    ) -> datetime_helpers.DatetimeWithNanoseconds:
         if isinstance(value, timestamp_pb2.Timestamp):
             if absent:
                 return None
-            return datetime.fromtimestamp(
-                value.seconds + value.nanos / 1e9, tz=timezone.utc,
-            )
+            return datetime_helpers.DatetimeWithNanoseconds.from_timestamp_pb(value)
         return value
 
     def to_proto(self, value) -> timestamp_pb2.Timestamp:
-        if isinstance(value, datetime):
-            return timestamp_pb2.Timestamp(
-                seconds=int(value.timestamp()), nanos=value.microsecond * 1000,
-            )
+        if isinstance(value, datetime_helpers.DatetimeWithNanoseconds):
+            return value.timestamp_pb()
         return value
 
 
